@@ -1,6 +1,6 @@
 import logging
 from collections import OrderedDict
-import formulas
+import formulas  # type: ignore
 
 from typing import (
     Any,
@@ -20,8 +20,8 @@ from business_rule_engine.exceptions import (
 
 class Rule():
 
-    def __init__(self, rulename, codition_requires_bool: bool = True) -> None:
-        self.codition_requires_bool = codition_requires_bool
+    def __init__(self, rulename, condition_requires_bool: bool = True) -> None:
+        self.condition_requires_bool = condition_requires_bool
         self.rulename: Text = rulename
         self.conditions: List[Text] = []
         self.actions: List[Text] = []
@@ -56,7 +56,7 @@ class Rule():
         condition_compiled = self._compile_condition(self.conditions)
         params_condition = self._get_params(params, condition_compiled, set_default_arg, default_arg)
         rvalue_condition = condition_compiled(**params_condition).tolist()
-        if self.codition_requires_bool and not isinstance(rvalue_condition, bool):
+        if self.condition_requires_bool and not isinstance(rvalue_condition, bool):
             raise ConditionReturnValueError('rule: {} - condition does not return a boolean value!'.format(self.rulename))
         self.status = bool(rvalue_condition)
         return rvalue_condition
@@ -78,9 +78,9 @@ class RuleParser():
 
     CUSTOM_FUNCTIONS: List[Text] = []
 
-    def __init__(self, codition_requires_bool: bool = True) -> None:
+    def __init__(self, condition_requires_bool: bool = True) -> None:
         self.rules: Dict[Text, Rule] = OrderedDict()
-        self.codition_requires_bool = codition_requires_bool
+        self.condition_requires_bool = condition_requires_bool
 
     def parsestr(self, text: Text) -> None:
         rulename = None
@@ -90,7 +90,8 @@ class RuleParser():
 
         for line in text.split('\n'):
             ignore_line = False
-            if line.lower().strip().startswith('rule'):
+            line = line.strip()  # The split on rule name doesn't work for multi-line w/o
+            if line.lower().startswith('rule'):
                 is_condition = False
                 is_action = False
                 rulename = line.split(' ', 1)[1].strip("\"")
